@@ -1,4 +1,4 @@
-__version__ = '0.1'
+__version__ = '0.2'
 
 import logging
 from loguru import logger
@@ -23,5 +23,6 @@ logging.basicConfig(handlers=[__InterceptHandler()], level=0)
 
 from experiment_server._main import server_process
 from experiment_server._client import Client
+from experiment_server._api import Experiment
 
-__all__ = [server_process, Client]
+__all__ = [server_process, Client, Experiment]
